==> sumo_0.25.0+dfsg1+6+16~ubuntu15.10.1.tar.xz: sumo-0.25.0+dfsg1+6+16~ubuntu15.10.1/src/gui/GUIEvent_Screenshot.h <==
/****************************************************************************/
/// @file    GUIEvent_Screenshot.h
/// @author  Michael Behrisch
/// @date    2015-08-25
/// @version $Id: GUIEvent_Screenshot.h 18761 2015-09-01 14:15:44Z behrisch $
///
// Event send when a screenshot should be made
/****************************************************************************/
// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
// Copyright (C) 2002-2015 DLR (http://www.dlr.de/) and contributors
/****************************************************************************/
//
//   This file is part of SUMO.
//   SUMO is free software: you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
/****************************************************************************/
#ifndef GUIEvent_Screenshot_h
#define GUIEvent_Screenshot_h


// ===========================================================================
// included modules
// ===========================================================================
#ifdef _MSC_VER
#include <windows_config.h>
#else
#include <config.h>
#endif

#include <string>
#include <iostream>
#include <utils/gui/events/GUIEvent.h>


// ===========================================================================
// class declarations
// ===========================================================================
class GUISUMOAbstractView;


// ===========================================================================
// class definitions
// ===========================================================================
/**
 * @class  GUIEvent_Screenshot
 *
 * Throw to GUIApplicationWindow from GUIRunThread to trigger a screenshot
 */
class GUIEvent_Screenshot : public GUIEvent {
public:
    /// constructor
    GUIEvent_Screenshot(GUISUMOAbstractView* view,
                        const std::string& file)
        : GUIEvent(EVENT_SCREENSHOT),
          myView(view), myFile(file)
    { }

    /// destructor
    ~GUIEvent_Screenshot() { }

public:
    /// @brief the view to save
    GUISUMOAbstractView* const myView;

    /// @brief the name of the file to save to
    const std::string myFile;

private:
    /// @brief Invalidated assignment operator
    GUIEvent_Screenshot& operator=(const GUIEvent_Screenshot& s);
};


#endif

/****************************************************************************/

==> sumo_0.32.0+dfsg1+9+22~ubuntu17.04.1.tar.xz: sumo-0.32.0+dfsg1+9+22~ubuntu17.04.1/src/gui/GUIEvent_Screenshot.h <==
/****************************************************************************/
// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
/****************************************************************************/
//
//   This program and the accompanying materials
//   are made available under the terms of the Eclipse Public License v2.0
//   which accompanies this distribution, and is available at
//   http://www.eclipse.org/legal/epl-v20.html
//
/****************************************************************************/
/// @file    GUIEvent_Screenshot.h
/// @author  Michael Behrisch
/// @date    2015-08-25
/// @version $Id$
///
// Event send when a screenshot should be made
/****************************************************************************/
#ifndef GUIEvent_Screenshot_h
#define GUIEvent_Screenshot_h


// ===========================================================================
// included modules
// ===========================================================================
#ifdef _MSC_VER
#include <windows_config.h>
#else
#include <config.h>
#endif

#include <string>
#include <iostream>
#include <utils/gui/events/GUIEvent.h>


// ===========================================================================
// class declarations
// ===========================================================================
class GUISUMOAbstractView;


// ===========================================================================
// class definitions
// ===========================================================================
/**
 * @class  GUIEvent_Screenshot
 *
 * Throw to GUIApplicationWindow from GUIRunThread to trigger a screenshot
 */
class GUIEvent_Screenshot : public GUIEvent {
public:
    /// constructor
    GUIEvent_Screenshot(GUISUMOAbstractView* view,
                        const std::string& file)
        : GUIEvent(EVENT_SCREENSHOT),
          myView(view), myFile(file) {
    }

    /// destructor
    ~GUIEvent_Screenshot() { }

public:
    /// @brief the view to save
    GUISUMOAbstractView* const myView;

    /// @brief the name of the file to save to
    const std::string myFile;

private:
    /// @brief Invalidated assignment operator
    GUIEvent_Screenshot& operator=(const GUIEvent_Screenshot& s);
};


#endif

/****************************************************************************/
